pub struct DelimiterSeparatedTextReadOptions {
pub field_delimiter: String,
pub max_line_size: u64,
pub quote: String,
pub header_lines_to_skip: u64,
pub escape: String,
pub value_treated_as_null: Option<String>,
}Expand description
Delimiter separated files may be compressed. The reader should autodetect this and decompress as needed.
Fields
field_delimiter: StringThe character(s) used to separate fields. Common values are comma, tab, and pipe. Multiple characters are allowed.
max_line_size: u64The maximum number of bytes to read from a single line. If a line exceeds this limit the resulting behavior is undefined.
quote: StringThe character(s) used to quote strings. Common values are single and double quotation marks.
header_lines_to_skip: u64The number of lines to skip at the beginning of the file.
escape: StringThe character used to escape characters in strings. Backslash is a common value. Note that a double quote mark can also be used as an escape character but the external quotes should be removed first.
value_treated_as_null: Option<String>If this value is encountered (including empty string), the resulting value is null instead. Leave unset to disable. If this value is provided, the effective schema of this file is comprised entirely of nullable strings. If not provided, the effective schema is instead made up of non-nullable strings.
Implementations
Sourceimpl DelimiterSeparatedTextReadOptions
impl DelimiterSeparatedTextReadOptions
Sourcepub fn value_treated_as_null(&self) -> &str
pub fn value_treated_as_null(&self) -> &str
Returns the value of value_treated_as_null, or the default value if value_treated_as_null is unset.